@@ -1,9 +1,8 @@
 from __init__ import Overwatch
 
 def main():
-    overwatch = Overwatch(battletag="Okush#11324", hero="dva", filter="best")
+    overwatch = Overwatch(battletag="Okush#11324")
  
-
     stats = overwatch()
 
     print(stats)
